@@ -10,7 +10,7 @@ pub fn get_test_names(config: &FlakeConfig) -> Result<Vec<String>, std::io::Erro
     if let Some(ref features) = config.features {
         cargo_cmd.push_str(" --features \"");
         cargo_cmd.push_str(features);
-        cargo_cmd.push_str("\"");
+        cargo_cmd.push('\"');
     };
     cargo_cmd.push_str(" -- --list");
 
@@ -75,15 +75,15 @@ fn main() -> Result<(), std::io::Error> {
             if let Some(ref features) = config.features {
                 cargo_cmd.push_str(" --features \"");
                 cargo_cmd.push_str(features);
-                cargo_cmd.push_str("\"");
+                cargo_cmd.push('\"');
             };
-            cargo_cmd.push_str(" ");
+            cargo_cmd.push(' ');
             cargo_cmd.push_str(&name);
 
             let setup = TestSetup {
                 name,
                 command: cargo_cmd,
-                iterations: config.iterations.unwrap_or(100),
+                iterations: config.iterations.unwrap_or(10),
             };
 
             run_single_test(setup).unwrap()
@@ -108,6 +108,7 @@ fn main() -> Result<(), std::io::Error> {
             );
         }
         println!("{}", table);
+        ::std::process::exit(1);
     } else {
         println!("no flakey tests detected")
     }
